@@ -6,8 +6,27 @@
 # under the terms of the MIT License; see LICENSE file for more details.
 
 """OArepo Micro API utilities."""
+from urllib.parse import urlparse
+
+from flask import request
 from invenio_indexer.utils import default_record_to_index
 
+API_ROUTES = [
+    '/oauth'
+]
+
+
+def is_api_request():
+    """Determines whether a request is to be served by micro API."""
+    # TODO: update OARepo Whitenoise to use this
+    path = urlparse(request.url).path
+    if not any([path.startswith(r) for r in API_ROUTES]):
+        accept = request.headers.get('Accept', '')
+        if 'html' in accept and 'download' not in request.args:
+            return False
+
+    return True
+
 
 def record_to_index_from_index_name(record):
     """Get index/doc_type given a record.
